instancelib.feature\_extraction.textinstance module
===================================================

.. automodule:: instancelib.feature_extraction.textinstance
   :members:
   :undoc-members:
   :show-inheritance:
